==> pointpos_api-0.0.16.tar.gz: doc/RolePermissionApi.md <==
# pointpos_api.api.RolePermissionApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createRolepermission**](RolePermissionApi.md#createRolepermission) | **Post** /role-permission | Create Rolepermission
[**deleteRolepermissionByID**](RolePermissionApi.md#deleteRolepermissionByID) | **Delete** /role-permission/:id | Delete Rolepermission By ID
[**findRolepermission**](RolePermissionApi.md#findRolepermission) | **Get** /role-permission | Get Rolepermission List
[**getRolepermissionByID**](RolePermissionApi.md#getRolepermissionByID) | **Get** /role-permission/:id | Get Rolepermission By ID
[**updateRolepermissionByID**](RolePermissionApi.md#updateRolepermissionByID) | **Put** /role-permission/:id | Update Rolepermission By ID


# **createRolepermission**
> RolePermission createRolepermission(authorization, xAPIKey, body, xPin)

Create Rolepermission

Create Rolepermission

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RolePermissionApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var body = new RolePermission(); // RolePermission | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.createRolepermission(authorization, xAPIKey, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling RolePermissionApi->createRolepermission: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **body** | [**RolePermission**](RolePermission.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**RolePermission**](RolePermission.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteRolepermissionByID**
> deleteRolepermissionByID(authorization, xAPIKey, id, xPin)

Delete Rolepermission By ID

Delete Rolepermission By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RolePermissionApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    api_instance.deleteRolepermissionByID(authorization, xAPIKey, id, xPin);
} catch (e) {
    print("Exception when calling RolePermissionApi->deleteRolepermissionByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findRolepermission**
> List<RolePermission> findRolepermission(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter)

Get Rolepermission List

Get Rolepermission  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RolePermissionApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var xPin = xPin_example; // String | PIN Number
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'updatedAt|>=|2017-05-15T17:49:16+07:00'  valid fields:   - id   - name   - isPrimitive   - isPublic   - isPinRequired   - createdAt   - createdBy   - updatedAt   - updatedBy  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findRolepermission(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling RolePermissionApi->findRolepermission: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10.0]
 **offset** | **num**|  | [optional] [default to 0.0]
 **sort** | **String**|  | [optional] [default to null]
 **direction** | **String**|  | [optional] [default to null]
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;updatedAt|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - id   - name   - isPrimitive   - isPublic   - isPinRequired   - createdAt   - createdBy   - updatedAt   - updatedBy  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] [default to const []]

### Return type

[**List<RolePermission>**](RolePermission.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getRolepermissionByID**
> RolePermission getRolepermissionByID(authorization, xAPIKey, id, xPin)

Get Rolepermission By ID

Get Rolepermission By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RolePermissionApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.getRolepermissionByID(authorization, xAPIKey, id, xPin);
    print(result);
} catch (e) {
    print("Exception when calling RolePermissionApi->getRolepermissionByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**RolePermission**](RolePermission.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateRolepermissionByID**
> RolePermission updateRolepermissionByID(authorization, xAPIKey, id, body, xPin)

Update Rolepermission By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RolePermissionApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var body = new RolePermission(); // RolePermission | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.updateRolepermissionByID(authorization, xAPIKey, id, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling RolePermissionApi->updateRolepermissionByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **body** | [**RolePermission**](RolePermission.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**RolePermission**](RolePermission.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> pointpos_api-0.2.1.tar.gz: doc/RolePermissionApi.md <==
# pointpos_api.api.RolePermissionApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createRolepermission**](RolePermissionApi.md#createRolepermission) | **Post** /role-permission | Create Rolepermission
[**deleteRolepermissionByID**](RolePermissionApi.md#deleteRolepermissionByID) | **Delete** /role-permission/:id | Delete Rolepermission By ID
[**findRolepermission**](RolePermissionApi.md#findRolepermission) | **Get** /role-permission | Get Rolepermission List
[**getRolepermissionByID**](RolePermissionApi.md#getRolepermissionByID) | **Get** /role-permission/:id | Get Rolepermission By ID
[**updateRolepermissionByID**](RolePermissionApi.md#updateRolepermissionByID) | **Put** /role-permission/:id | Update Rolepermission By ID


# **createRolepermission**
> RolePermission createRolepermission(authorization, xAPIKey, body, xPin)

Create Rolepermission

Create Rolepermission

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RolePermissionApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var body = new RolePermission(); // RolePermission | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.createRolepermission(authorization, xAPIKey, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling RolePermissionApi->createRolepermission: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **body** | [**RolePermission**](RolePermission.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**RolePermission**](RolePermission.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteRolepermissionByID**
> deleteRolepermissionByID(authorization, xAPIKey, id, xPin)

Delete Rolepermission By ID

Delete Rolepermission By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RolePermissionApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    api_instance.deleteRolepermissionByID(authorization, xAPIKey, id, xPin);
} catch (e) {
    print("Exception when calling RolePermissionApi->deleteRolepermissionByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findRolepermission**
> List<RolePermission> findRolepermission(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter, withDeleted)

Get Rolepermission List

Get Rolepermission  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RolePermissionApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var xPin = xPin_example; // String | PIN Number
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'updatedAt|>=|2017-05-15T17:49:16+07:00'  valid fields:   - id   - name   - isPrimitive   - isPublic   - isPinRequired   - createdAt   - createdBy   - updatedAt   - updatedBy  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 
var withDeleted = true; // bool | Return with deleted resource

try { 
    var result = api_instance.findRolepermission(authorization, xAPIKey, xPin, limit, offset, sort, direction, filter, withDeleted);
    print(result);
} catch (e) {
    print("Exception when calling RolePermissionApi->findRolepermission: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10.0]
 **offset** | **num**|  | [optional] [default to 0.0]
 **sort** | **String**|  | [optional] [default to null]
 **direction** | **String**|  | [optional] [default to null]
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;updatedAt|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - id   - name   - isPrimitive   - isPublic   - isPinRequired   - createdAt   - createdBy   - updatedAt   - updatedBy  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] [default to const []]
 **withDeleted** | **bool**| Return with deleted resource | [optional] [default to false]

### Return type

[**List<RolePermission>**](RolePermission.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getRolepermissionByID**
> RolePermission getRolepermissionByID(authorization, xAPIKey, id, xPin)

Get Rolepermission By ID

Get Rolepermission By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RolePermissionApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.getRolepermissionByID(authorization, xAPIKey, id, xPin);
    print(result);
} catch (e) {
    print("Exception when calling RolePermissionApi->getRolepermissionByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**RolePermission**](RolePermission.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateRolepermissionByID**
> RolePermission updateRolepermissionByID(authorization, xAPIKey, id, body, xPin)

Update Rolepermission By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//pointpos_api.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//pointpos_api.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new RolePermissionApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = xAPIKey_example; // String | API Key
var id = id_example; // String | 
var body = new RolePermission(); // RolePermission | 
var xPin = xPin_example; // String | PIN Number

try { 
    var result = api_instance.updateRolepermissionByID(authorization, xAPIKey, id, body, xPin);
    print(result);
} catch (e) {
    print("Exception when calling RolePermissionApi->updateRolepermissionByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | [default to null]
 **xAPIKey** | **String**| API Key | [default to null]
 **id** | **String**|  | [default to null]
 **body** | [**RolePermission**](RolePermission.md)|  | 
 **xPin** | **String**| PIN Number | [optional] [default to null]

### Return type

[**RolePermission**](RolePermission.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
